% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stat_pointinterval.R, R/stat_pointintervalh.R
\name{stat_pointinterval}
\alias{stat_pointinterval}
\alias{stat_pointintervalh}
\title{Point summary + multiple probability interval plots (ggplot stat)}
\usage{
stat_pointinterval(mapping = NULL, data = NULL,
  geom = "pointinterval", position = "identity", ...,
  point_interval = median_qi, fun.data = NULL, .width = c(0.66,
  0.95), .prob, fun.args = list(), na.rm = FALSE,
  show.legend = FALSE, inherit.aes = TRUE)

stat_pointintervalh(mapping = NULL, data = NULL,
  geom = "pointintervalh", position = "identity", ...,
  point_interval = median_qi, fun.data = NULL, .width = c(0.66,
  0.95), .prob, fun.args = list(), na.rm = FALSE,
  show.legend = FALSE, inherit.aes = TRUE)
}
\arguments{
\item{mapping}{The aesthetic mapping, usually constructed with
\code{\link{aes}} or \code{\link{aes_string}}. Only needs to be set at the
layer level if you are overriding the plot defaults.}

\item{data}{A layer specific dataset - only needed if you want to override
the plot defaults.}

\item{geom}{Use to override the default connection between
\code{geom_pointinterval}/\code{geom_pointintervalh} and \code{stat_pointinterval}/\code{stat_pointintervalh}.}

\item{position}{The position adjustment to use for overlapping points on this layer.}

\item{...}{Other arguments passed to \code{\link{layer}}. They may also be arguments to the paired geom.}

\item{point_interval}{A function that when given a vector should
return a data frame with variables \code{y}, \code{ymin}, \code{ymax}, and \code{.width}; or
\code{x}, \code{xmin}, \code{xmax}, and \code{.width}. \strong{Either is acceptable}: output
will be converted into the \code{y}-based aesthetics for \code{stat_pointinterval} and the
\code{x}-based aesthetics for \code{stat_pointintervalh}. See the \code{point_interval} family of functions.}

\item{fun.data}{Similar to \code{point_interval}, for compatibility with \code{stat_summary}.
Note: if the summary function is passed using \code{fun.data}, the \code{x} and \code{y}-based aesthetics
are not converted to the correct form automatically.}

\item{.width}{The \code{.width} argument passed to \code{point_interval}.}

\item{.prob}{Deprecated. Use \code{.width} instead.}

\item{fun.args}{Other optional arguments passed to \code{fun.data}.}

\item{na.rm}{If \code{FALSE}, the default, missing values are removed with a warning. If \code{TRUE}, missing
values are silently removed.}

\item{show.legend}{Should this later be included in the legends? Default is \code{FALSE}, unlike most stats/geoms,
to match its common use cases; N.B. this is unlike most geoms, which have a default of \code{NA}.}

\item{inherit.aes}{If \code{FALSE}, overrides the default aesthetics, rather than combining with them. This is
most useful for helper functions that define both data and aesthetics and shouldn't inherit behavior from the
default plot specification, e.g. borders.}
}
\description{
A combination of \code{\link{stat_summary}} / \code{\link{stat_summaryh}} and
\code{\link{geom_pointinterval}} / \code{\link{geom_pointintervalh}} with sensible defaults.
While the corresponding \code{geom}s are intended for use on
data frames that have already been summarized using a \code{\link{point_interval}}
function, these \code{stat}s are intended for use directly on data frames of draws, and
will perform the summarization using a \code{\link{point_interval}} function.
}
\examples{

library(magrittr)
library(ggplot2)

data(RankCorr, package = "tidybayes")

RankCorr \%>\%
  spread_draws(u_tau[i]) \%>\%
  ggplot(aes(y = i, x = u_tau)) +
  stat_pointintervalh(.width = c(.66, .95))

RankCorr \%>\%
  spread_draws(u_tau[i]) \%>\%
  ggplot(aes(x = i, y = u_tau)) +
  stat_pointinterval(.width = c(.66, .95))

}
\seealso{
See \code{\link{geom_pointinterval}} / \code{\link{geom_pointintervalh}} for the geom versions, intended
for use on points and intervals that have already been summarized using a \code{\link{point_interval}} function.
See \code{\link{stat_interval}} / \code{\link{stat_intervalh}} for a similar stat intended for intervals without
point summaries.
}
